atom-validator.parser

XML parsing for Atom feeds using clojure.data.xml.

XML parsing for Atom feeds using clojure.data.xml.
raw docstring

atom-nsclj


parse-entryclj

(parse-entry entry-el)

Parse an Atom entry element into a Clojure map.

Parse an Atom entry element into a Clojure map.
raw docstring

parse-feedclj

(parse-feed source)

Parse an Atom feed from XML string or input stream. Returns a map with :id, :title, :updated, :entries, etc.

Parse an Atom feed from XML string or input stream.
Returns a map with :id, :title, :updated, :entries, etc.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries