atom-validator.rules

RFC 4287 structural validation rules for Atom feeds.

RFC 4287 structural validation rules for Atom feeds.
raw docstring

parse-datetimeclj

(parse-datetime s)

Parse an RFC 3339 datetime string. Returns nil if invalid.

Parse an RFC 3339 datetime string. Returns nil if invalid.
raw docstring

rfc3339-formatterclj

RFC 3339 date-time formatter.

RFC 3339 date-time formatter.
raw docstring

rfc3339-no-ms-formatterclj

RFC 3339 without milliseconds.

RFC 3339 without milliseconds.
raw docstring

validate-entryclj

(validate-entry entry idx)

Validate a single entry. Returns a sequence of errors/warnings.

Validate a single entry. Returns a sequence of errors/warnings.
raw docstring

validate-entry-content-or-linkclj

(validate-entry-content-or-link entry idx)

Entry MUST contain content, or at least one link with rel='alternate'.

Entry MUST contain content, or at least one link with rel='alternate'.
raw docstring

validate-entry-idclj

(validate-entry-id entry idx)

Entry MUST have exactly one id element.

Entry MUST have exactly one id element.
raw docstring

validate-entry-titleclj

(validate-entry-title entry idx)

Entry MUST have exactly one title element.

Entry MUST have exactly one title element.
raw docstring

validate-entry-updatedclj

(validate-entry-updated entry idx)

Entry MUST have exactly one updated element with valid RFC 3339 date.

Entry MUST have exactly one updated element with valid RFC 3339 date.
raw docstring

validate-feed-authorclj

(validate-feed-author feed)

Feed SHOULD have author(s), or all entries must have authors.

Feed SHOULD have author(s), or all entries must have authors.
raw docstring

validate-feed-freshnessclj

(validate-feed-freshness feed)

Feed updated timestamp should be >= the newest entry's updated timestamp. This is Issue #2 from the validator requirements.

Feed updated timestamp should be >= the newest entry's updated timestamp.
This is Issue #2 from the validator requirements.
raw docstring

validate-feed-idclj

(validate-feed-id feed)

Feed MUST have exactly one id element.

Feed MUST have exactly one id element.
raw docstring

validate-feed-structureclj

(validate-feed-structure feed)

Validate feed structure per RFC 4287. Returns {:errors [...] :warnings [...]}.

Validate feed structure per RFC 4287. Returns {:errors [...] :warnings [...]}.
raw docstring

validate-feed-titleclj

(validate-feed-title feed)

Feed MUST have exactly one title element.

Feed MUST have exactly one title element.
raw docstring

validate-feed-updatedclj

(validate-feed-updated feed)

Feed MUST have exactly one updated element with valid RFC 3339 date.

Feed MUST have exactly one updated element with valid RFC 3339 date.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries