XML parsing for Atom feeds using clojure.data.xml.
XML parsing for Atom feeds using clojure.data.xml.
(parse-entry entry-el)Parse an Atom entry element into a Clojure map.
Parse an Atom entry element into a Clojure map.
(parse-feed source)Parse an Atom feed from XML string or input stream. Returns a map with :id, :title, :updated, :entries, etc.
Parse an Atom feed from XML string or input stream. Returns a map with :id, :title, :updated, :entries, etc.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |