RFC 4287 structural validation rules for Atom feeds.
RFC 4287 structural validation rules for Atom feeds.
(parse-datetime s)Parse an RFC 3339 datetime string. Returns nil if invalid.
Parse an RFC 3339 datetime string. Returns nil if invalid.
RFC 3339 without milliseconds.
RFC 3339 without milliseconds.
(validate-entry entry idx)Validate a single entry. Returns a sequence of errors/warnings.
Validate a single entry. Returns a sequence of errors/warnings.
(validate-entry-content-or-link entry idx)Entry MUST contain content, or at least one link with rel='alternate'.
Entry MUST contain content, or at least one link with rel='alternate'.
(validate-entry-id entry idx)Entry MUST have exactly one id element.
Entry MUST have exactly one id element.
(validate-entry-title entry idx)Entry MUST have exactly one title element.
Entry MUST have exactly one title element.
(validate-entry-updated entry idx)Entry MUST have exactly one updated element with valid RFC 3339 date.
Entry MUST have exactly one updated element with valid RFC 3339 date.
(validate-feed-author feed)Feed SHOULD have author(s), or all entries must have authors.
Feed SHOULD have author(s), or all entries must have authors.
(validate-feed-freshness feed)Feed updated timestamp should be >= the newest entry's updated timestamp. This is Issue #2 from the validator requirements.
Feed updated timestamp should be >= the newest entry's updated timestamp. This is Issue #2 from the validator requirements.
(validate-feed-id feed)Feed MUST have exactly one id element.
Feed MUST have exactly one id element.
(validate-feed-structure feed)Validate feed structure per RFC 4287. Returns {:errors [...] :warnings [...]}.
Validate feed structure per RFC 4287. Returns {:errors [...] :warnings [...]}.
(validate-feed-title feed)Feed MUST have exactly one title element.
Feed MUST have exactly one title element.
(validate-feed-updated feed)Feed MUST have exactly one updated element with valid RFC 3339 date.
Feed MUST have exactly one updated element with valid RFC 3339 date.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |