URL/IRI validation for Atom feed elements. Uses lambdaisland/uri for parsing.
URL/IRI validation for Atom feed elements. Uses lambdaisland/uri for parsing.
(absolute-url? parsed)Check if URL is absolute (has scheme and host).
Check if URL is absolute (has scheme and host).
(parse-url url-str)Parse a URL string. Returns the parsed URI or nil if invalid.
Parse a URL string. Returns the parsed URI or nil if invalid.
Suffixes that suggest a typo where someone merged host and path.
Suffixes that suggest a typo where someone merged host and path.
(suspicious-tld? tld)Check if TLD looks like a typo (e.g., 'shsite' contains 'site').
Check if TLD looks like a typo (e.g., 'shsite' contains 'site').
(tag-uri? url-str)Check if a URL is a tag: URI per RFC 4151 (e.g., tag:github.com,2008:...). Format: tag:<authority>,<date>:<specific>
Check if a URL is a tag: URI per RFC 4151 (e.g., tag:github.com,2008:...). Format: tag:<authority>,<date>:<specific>
(urn? url-str)Check if a URL is a URN (e.g., urn:uuid:...).
Check if a URL is a URN (e.g., urn:uuid:...).
(valid-host? parsed)Check if URL has a valid host.
Check if URL has a valid host.
(valid-iri-for-id? url-str)Check if string is a valid IRI for atom:id per RFC 4287. Allows: URNs (urn:uuid:...), tag URIs (tag:...), and absolute URLs.
Check if string is a valid IRI for atom:id per RFC 4287. Allows: URNs (urn:uuid:...), tag URIs (tag:...), and absolute URLs.
(valid-scheme? parsed)Check if URL has a valid scheme (http, https).
Check if URL has a valid scheme (http, https).
(validate-entry-urls entry idx)Validate all URLs in an entry (id, links). Note: atom:id can be a URN or tag: URI per RFC 4287/RFC 4151.
Validate all URLs in an entry (id, links). Note: atom:id can be a URN or tag: URI per RFC 4287/RFC 4151.
(validate-feed-urls feed)Validate all URLs in a feed and its entries. Returns {:errors [...] :warnings [...]}.
Validate all URLs in a feed and its entries.
Returns {:errors [...] :warnings [...]}.(validate-url url-str context & {:keys [allow-iri?] :or {allow-iri? false}})Validate a URL string. Returns error map or nil if valid. URN identifiers (urn:uuid:...) and tag: URIs are valid for atom:id per RFC 4287.
Validate a URL string. Returns error map or nil if valid. URN identifiers (urn:uuid:...) and tag: URIs are valid for atom:id per RFC 4287.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |