atom-validator.url

URL/IRI validation for Atom feed elements. Uses lambdaisland/uri for parsing.

URL/IRI validation for Atom feed elements.
Uses lambdaisland/uri for parsing.
raw docstring

absolute-url?clj

(absolute-url? parsed)

Check if URL is absolute (has scheme and host).

Check if URL is absolute (has scheme and host).
sourceraw docstring

parse-urlclj

(parse-url url-str)

Parse a URL string. Returns the parsed URI or nil if invalid.

Parse a URL string. Returns the parsed URI or nil if invalid.
sourceraw docstring

suspicious-tld-suffixesclj

Suffixes that suggest a typo where someone merged host and path.

Suffixes that suggest a typo where someone merged host and path.
sourceraw docstring

suspicious-tld?clj

(suspicious-tld? tld)

Check if TLD looks like a typo (e.g., 'shsite' contains 'site').

Check if TLD looks like a typo (e.g., 'shsite' contains 'site').
sourceraw docstring

urn?clj

(urn? url-str)

Check if a URL is a URN (e.g., urn:uuid:...).

Check if a URL is a URN (e.g., urn:uuid:...).
sourceraw docstring

valid-host?clj

(valid-host? parsed)

Check if URL has a valid host.

Check if URL has a valid host.
sourceraw docstring

valid-scheme?clj

(valid-scheme? parsed)

Check if URL has a valid scheme (http, https).

Check if URL has a valid scheme (http, https).
sourceraw docstring

validate-entry-urlsclj

(validate-entry-urls entry idx)

Validate all URLs in an entry (id, links). Note: atom:id can be a URN (e.g., urn:uuid:...) per RFC 4287.

Validate all URLs in an entry (id, links).
Note: atom:id can be a URN (e.g., urn:uuid:...) per RFC 4287.
sourceraw docstring

validate-feed-urlsclj

(validate-feed-urls feed)

Validate all URLs in a feed and its entries. Returns {:errors [...] :warnings [...]}.

Validate all URLs in a feed and its entries.
Returns {:errors [...] :warnings [...]}.
sourceraw docstring

validate-urlclj

(validate-url url-str context & {:keys [allow-urn?] :or {allow-urn? false}})

Validate a URL string. Returns error map or nil if valid. URN identifiers (urn:uuid:...) are always valid for atom:id elements.

Validate a URL string. Returns error map or nil if valid.
URN identifiers (urn:uuid:...) are always valid for atom:id elements.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries